@@ -64,9 +64,9 @@ def _cli_wrapper(fn: WrappedCommandT) -> WrappedCommandT:
             from dipdup.sentry import save_crashdump
 
             crashdump_path = save_crashdump(e)
-            _logger.error(f'Unhandled exception caught, crashdump saved to `{crashdump_path}`')
+            _logger.info(f'Unhandled exception caught, crashdump saved to `{crashdump_path}`')
             _print_help(e)
-            raise
+            raise e
 
     return cast(WrappedCommandT, wrapper)
 
@@ -122,8 +122,10 @@ async def cli(ctx: click.Context, config: list[str], env_file: list[str]) -> Non
 
     Issues: https://github.com/dipdup-io/dipdup/issues
     """
-    if env.get('DIPDUP_PYTEZOS'):
-        _logger.warning('PyTezos image is not actively maintained and may be removed in future releases')
+    if env.DOCKER_IMAGE == 'pytezos':
+        _logger.warning('`-pytezos` image is deprecated and will be removed in the next major release')
+    elif env.DOCKER_IMAGE == 'slim':
+        _logger.warning('`-slim` image will be based on Ubuntu instead of Alpine in the next major release')
 
     # NOTE: Workaround for help pages. First argument check is for the test runner.
     args = sys.argv[1:] if sys.argv else ['--help']
@@ -202,7 +204,7 @@ async def cli(ctx: click.Context, config: list[str], env_file: list[str]) -> Non
 async def run(ctx: click.Context) -> None:
     """Run indexer.
 
-    Execution can be gracefully interrupted with `Ctrl+C` or `SIGTERM` signal.
+    Execution can be gracefully interrupted with `Ctrl+C` or `SIGINT` signal.
     """
     from dipdup.config import DipDupConfig
     from dipdup.dipdup import DipDup
