@@ -20,6 +20,7 @@ from typing import cast
 from tortoise import Tortoise
 from tortoise.exceptions import OperationalError
 
+from dipdup import env
 from dipdup.config import BigMapIndexConfig
 from dipdup.config import ContractConfig
 from dipdup.config import DipDupConfig
@@ -29,6 +30,7 @@ from dipdup.config import HandlerConfig
 from dipdup.config import HeadIndexConfig
 from dipdup.config import HookConfig
 from dipdup.config import OperationIndexConfig
+from dipdup.config import OperationUnfilteredIndexConfig
 from dipdup.config import PostgresDatabaseConfig
 from dipdup.config import ResolvedIndexConfigU
 from dipdup.config import TokenTransferIndexConfig
@@ -60,7 +62,6 @@ from dipdup.utils.database import execute_sql
 from dipdup.utils.database import execute_sql_query
 from dipdup.utils.database import get_connection
 from dipdup.utils.database import wipe_schema
-from dipdup.utils.sys import is_in_tests
 
 DatasourceT = TypeVar('DatasourceT', bound=Datasource)
 
@@ -310,7 +311,7 @@ class DipDupContext:
         datasource_name = index_config.datasource.name
         datasource = self.get_tzkt_datasource(datasource_name)
 
-        if isinstance(index_config, OperationIndexConfig):
+        if isinstance(index_config, (OperationIndexConfig, OperationUnfilteredIndexConfig)):
             index = OperationIndex(self, index_config, datasource)
         elif isinstance(index_config, BigMapIndexConfig):
             index = BigMapIndex(self, index_config, datasource)
@@ -324,13 +325,20 @@ class DipDupContext:
             raise NotImplementedError
 
         await datasource.add_index(index_config)
-        for handler_config in index_config.handlers:
+        handlers = (
+            (index_config.handler_config,)
+            if isinstance(index_config, OperationUnfilteredIndexConfig)
+            else index_config.handlers
+        )
+        for handler_config in handlers:
             self._callbacks.register_handler(handler_config)
         await index.initialize_state(state)
 
         # NOTE: IndexDispatcher will handle further initialization when it's time
         pending_indexes.append(index)
 
+    # TODO: disable_index(name: str)
+
     async def update_contract_metadata(
         self,
         network: str,
@@ -416,7 +424,7 @@ class DipDupContext:
 class HookContext(DipDupContext):
     """Execution context of hook callbacks.
 
-    :param hook_config: Configuration of current hook
+    :param hook_config: Configuration of the current hook
     """
 
     def __init__(
@@ -499,7 +507,7 @@ class TemplateValuesdict(dict[str, Any]):
 class HandlerContext(DipDupContext):
     """Execution context of handler callbacks.
 
-    :param handler_config: Configuration of current handler
+    :param handler_config: Configuration of the current handler
     :param datasource: Index datasource instance
     """
 
@@ -551,6 +559,7 @@ class CallbackManager:
         while True:
             while pending_hooks:
                 await pending_hooks.popleft()
+            # TODO: Replace with asyncio.Event
             await asyncio.sleep(1)
 
     def register_handler(self, handler_config: HandlerConfig) -> None:
@@ -638,7 +647,7 @@ class CallbackManager:
     ) -> None:
         """Execute SQL script included with the project"""
         # NOTE: Modified `package_path` breaks SQL discovery.
-        if is_in_tests():
+        if env.TEST:
             return
 
         sql_path = self._get_sql_path(ctx, name)
@@ -701,7 +710,7 @@ class CallbackManager:
 
     def _get_sql_path(self, ctx: 'DipDupContext', name: str) -> Path:
         subpackages = name.split('.')
-        sql_path = Path(ctx.config.package_path, 'sql', *subpackages)
+        sql_path = Path(env.get_package_path(ctx.config.package), 'sql', *subpackages)
         if not sql_path.exists():
             raise InitializationRequiredError(f'Missing SQL directory for hook `{name}`')
 
