@@ -1,5 +1,7 @@
 from enum import Enum
 
+from dipdup import env
+
 
 class LoggingValues(Enum):
     """Enum for `logging` field values."""
@@ -19,23 +21,42 @@ class MessageType(Enum):
     event = 'event'
 
 
-class IndexType(Enum):
-    """Enum for `dipdup.models.Index`"""
+# TODO: Remove in 7.0
+if env.NEXT:
 
-    operation = 'operation'
-    big_map = 'big_map'
-    head = 'head'
-    token_transfer = 'token_transfer'
-    event = 'event'
+    class IndexType(Enum):
+        """Enum for `dipdup.models.Index`"""
+
+        operation = 'operation'
+        operation_unfiltered = 'operation_unfiltered'
+        big_map = 'big_map'
+        head = 'head'
+        token_transfer = 'token_transfer'
+        event = 'event'
+
+else:
+
+    class IndexType(Enum):  # type: ignore[no-redef]
+        """Enum for `dipdup.models.Index`"""
+
+        operation = 'operation'
+        big_map = 'big_map'
+        head = 'head'
+        token_transfer = 'token_transfer'
+        event = 'event'
 
 
 class OperationType(Enum):
+    """Type of blockchain operation"""
+
     transaction = 'transaction'
     origination = 'origination'
     migration = 'migration'
 
 
 class SkipHistory(Enum):
+    """Whether to skip indexing operation history and use only current state"""
+
     never = 'never'
     once = 'once'
     always = 'always'
@@ -53,6 +74,8 @@ class IndexStatus(Enum):
 
 # NOTE: Used as a key in config, must inherit from str
 class ReindexingReason(str, Enum):
+    """Reason that caused reindexing"""
+
     manual = 'manual'
     migration = 'migration'
     rollback = 'rollback'
@@ -61,6 +84,8 @@ class ReindexingReason(str, Enum):
 
 
 class ReindexingAction(Enum):
+    """Action that should be performed on reindexing"""
+
     exception = 'exception'
     wipe = 'wipe'
     ignore = 'ignore'
