@@ -7,9 +7,12 @@ from typing import Iterator
 from typing import Sequence
 
 from dipdup.config import OperationHandlerConfig
+from dipdup.config import OperationHandlerConfigU
 from dipdup.config import OperationHandlerOriginationPatternConfig as OriginationPatternConfig
 from dipdup.config import OperationHandlerTransactionPatternConfig as TransactionPatternConfig
 from dipdup.config import OperationIndexConfig
+from dipdup.config import OperationIndexConfigU
+from dipdup.config import OperationUnfilteredIndexConfig
 from dipdup.context import DipDupContext
 from dipdup.datasources.tzkt.datasource import TzktDatasource
 from dipdup.enums import MessageType
@@ -17,14 +20,16 @@ from dipdup.exceptions import ConfigInitializationException
 from dipdup.exceptions import FrameworkException
 from dipdup.index import Index
 from dipdup.indexes.operation.fetcher import OperationFetcher
+from dipdup.indexes.operation.fetcher import OperationUnfilteredFetcher
 from dipdup.indexes.operation.matcher import MatchedOperationsT
-from dipdup.indexes.operation.matcher import OperationHandlerArgumentT
+from dipdup.indexes.operation.matcher import OperationHandlerArgumentU
 from dipdup.indexes.operation.matcher import OperationSubgroup
 from dipdup.indexes.operation.matcher import match_operation_subgroup
+from dipdup.indexes.operation.matcher import match_operation_unfiltered_subgroup
 from dipdup.models import OperationData
 from dipdup.prometheus import Metrics
 
-_logger = logging.getLogger('dipdup_matcher')
+_logger = logging.getLogger('dipdup.matcher')
 
 OperationQueueItem = tuple[OperationSubgroup, ...]
 
@@ -145,10 +150,15 @@ def extract_operation_subgroups(
 
 
 class OperationIndex(
-    Index[OperationIndexConfig, OperationQueueItem, TzktDatasource],
+    Index[OperationIndexConfigU, OperationQueueItem, TzktDatasource],
     message_type=MessageType.operation,
 ):
-    def __init__(self, ctx: DipDupContext, config: OperationIndexConfig, datasource: TzktDatasource) -> None:
+    def __init__(
+        self,
+        ctx: DipDupContext,
+        config: OperationIndexConfigU,
+        datasource: TzktDatasource,
+    ) -> None:
         super().__init__(ctx, config, datasource)
         self._entrypoint_filter: set[str | None] = set()
         self._address_filter: set[str] = set()
@@ -158,6 +168,9 @@ class OperationIndex(
         self.push_realtime_message(operation_subgroups)
 
     async def get_filters(self) -> tuple[set[str | None], set[str], set[int]]:
+        if isinstance(self._config, OperationUnfilteredIndexConfig):
+            return set(), set(), set()
+
         if self._entrypoint_filter or self._address_filter or self._code_hash_filter:
             return self._entrypoint_filter, self._address_filter, self._code_hash_filter
 
@@ -208,12 +221,22 @@ class OperationIndex(
 
         first_level = index_level + 1
         self._logger.info('Fetching operations from level %s to %s', first_level, sync_level)
-        fetcher = await OperationFetcher.create(
-            self._config,
-            self._datasource,
-            first_level,
-            sync_level,
-        )
+
+        fetcher: OperationFetcher | OperationUnfilteredFetcher
+        if isinstance(self._config, OperationIndexConfig):
+            fetcher = await OperationFetcher.create(
+                self._config,
+                self._datasource,
+                first_level,
+                sync_level,
+            )
+        elif isinstance(self._config, OperationUnfilteredIndexConfig):
+            fetcher = await OperationUnfilteredFetcher.create(
+                self._config,
+                self._datasource,
+                first_level,
+                sync_level,
+            )
 
         async for level, operations in fetcher.fetch_by_level():
             if Metrics.enabled:
@@ -252,10 +275,17 @@ class OperationIndex(
         self._logger.debug('Processing %s operation subgroups of level %s', len(operation_subgroups), batch_level)
         matched_handlers: deque[MatchedOperationsT] = deque()
         for operation_subgroup in operation_subgroups:
-            subgroup_handlers = match_operation_subgroup(
-                self._config.handlers,
-                operation_subgroup,
-            )
+            if isinstance(self._config, OperationUnfilteredIndexConfig):
+                subgroup_handlers = match_operation_unfiltered_subgroup(
+                    self._config,
+                    operation_subgroup,
+                )
+            else:
+                subgroup_handlers = match_operation_subgroup(
+                    self._config.handlers,
+                    operation_subgroup,
+                )
+
             if subgroup_handlers:
                 self._logger.info(
                     '%s: `%s` handler matched!',
@@ -269,19 +299,19 @@ class OperationIndex(
 
         # NOTE: We still need to bump index level but don't care if it will be done in existing transaction
         if not matched_handlers:
-            await self.state.update_status(level=batch_level)
+            await self._update_state(level=batch_level)
             return
 
         async with self._ctx._transactions.in_transaction(batch_level, sync_level, self.name):
             for operation_subgroup, handler_config, args in matched_handlers:
                 await self._call_matched_handler(handler_config, operation_subgroup, args)
-            await self.state.update_status(level=batch_level)
+            await self._update_state(level=batch_level)
 
     async def _call_matched_handler(
         self,
-        handler_config: OperationHandlerConfig,
+        handler_config: OperationHandlerConfigU,
         operation_subgroup: OperationSubgroup,
-        args: Sequence[OperationHandlerArgumentT],
+        args: Sequence[OperationHandlerArgumentU],
     ) -> None:
         if not handler_config.parent:
             raise ConfigInitializationException
