@@ -29,8 +29,11 @@ from dipdup.exceptions import ProjectImportError
 
 def import_submodules(package: str) -> Dict[str, types.ModuleType]:
     """Recursively import all submodules of a package"""
+    module = importlib.import_module(package)
     results = {}
-    for _, name, is_pkg in pkgutil.walk_packages((package,)):
+    for subpackage in pkgutil.walk_packages(module.__path__):
+        name = subpackage.name
+        is_pkg = subpackage.ispkg
         full_name = package + '.' + name
         results[full_name] = importlib.import_module(full_name)
         if is_pkg:
@@ -145,14 +148,6 @@ def import_from(module: str, obj: str) -> Any:
         raise ProjectImportError(module, obj) from e
 
 
-def exclude_none(config_json: Any) -> Any:
-    if isinstance(config_json, (list, tuple)):
-        return [exclude_none(i) for i in config_json if i is not None]
-    if isinstance(config_json, dict):
-        return {k: exclude_none(v) for k, v in config_json.items() if v is not None}
-    return config_json
-
-
 def json_dumps_decimals(obj: Any) -> str:
     def _default(obj: Any) -> Any:
         if isinstance(obj, Decimal):
